summaryrefslogtreecommitdiff
path: root/Debian/Debhelper/Dh_Buildsystems.pm
diff options
context:
space:
mode:
authorModestas Vainius <modestas@vainius.eu>2009-06-15 16:20:11 +0300
committerModestas Vainius <modestas@vainius.eu>2009-06-17 22:44:31 +0300
commit95f0a0968c30a6737c3f321f305985b3fd33a63e (patch)
treee0bf3bd0f3745792682e7f4397c7f7b84072761b /Debian/Debhelper/Dh_Buildsystems.pm
parent49b64c7852744f54250121b1c60544e1f5de70b6 (diff)
Some cosmetic changes in the comments and strings.
* buildsystem -> build system * dh_auto build system -> debhelper build system * plugin -> class * a few rewording changes in the comments. * Enhance python_distutils::DESCRIPTION().
Diffstat (limited to 'Debian/Debhelper/Dh_Buildsystems.pm')
-rw-r--r--Debian/Debhelper/Dh_Buildsystems.pm18
1 files changed, 9 insertions, 9 deletions
diff --git a/Debian/Debhelper/Dh_Buildsystems.pm b/Debian/Debhelper/Dh_Buildsystems.pm
index 6748a746..0e11dba8 100644
--- a/Debian/Debhelper/Dh_Buildsystems.pm
+++ b/Debian/Debhelper/Dh_Buildsystems.pm
@@ -1,4 +1,4 @@
# A module for loading and managing debhelper buildsystem plugins.
# This module is intended to be used by all dh_auto_* helper commands.
#
# Copyright: © 2009 Modestas Vainius
@@ -15,7 +15,7 @@ use base 'Exporter';
our @EXPORT=qw(&buildsystems_init &buildsystems_do &load_buildsystem &load_all_buildsystems);
# Historical order must be kept for backwards compatibility. New
# buildsystems MUST be added to the END of the list.
our @BUILDSYSTEMS = (
"autoconf",
"perl_makemaker",
@@ -38,7 +38,7 @@ sub create_buildsystem_instance {
eval "use $module";
if ($@) {
- error("unable to load buildsystem class '$system': $@");
+ error("unable to load build system class '$system': $@");
}
if (!exists $bsopts{builddir} && defined $opt_builddir) {
@@ -50,8 +50,8 @@ sub create_buildsystem_instance {
return $module->new(%bsopts);
}
# Similar to create_buildsystem_instance(), but it attempts to autoselect
# a buildsystem if none was specified. In case autoselection fails, undef
# is returned.
sub load_buildsystem {
my $system=shift;
@@ -88,15 +88,15 @@ sub load_all_buildsystems {
}
}
# Push debhelper built-in buildsystems first
for my $name (@BUILDSYSTEMS) {
- error("debhelper built-in buildsystem '$name' could not be found/loaded")
+ error("debhelper built-in build system '$name' could not be found/loaded")
if not exists $buildsystems{$name};
push @buildsystems, $buildsystems{$name};
delete $buildsystems{$name};
}
# The rest are 3rd party buildsystems
for my $name (keys %buildsystems) {
my $inst = $buildsystems{$name};
$inst->{thirdparty} = 1;
@@ -132,7 +132,7 @@ sub buildsystems_init {
sub buildsystems_list {
my $step=shift;
# List buildsystems (including auto and specified status)
my ($auto, $specified);
my @buildsystems = load_all_buildsystems();
for my $inst (@buildsystems) {
@@ -1,4 +1,4 @@
-# A module for loading and managing debhelper buildsystem plugins.
+# A module for loading and managing debhelper build system plugins.
# This module is intended to be used by all dh_auto_* helper commands.
#
@@ -15,7 +15,7 @@ use base 'Exporter';
our @EXPORT=qw(&buildsystems_init &buildsystems_do &load_buildsystem &load_all_buildsystems);
# Historical order must be kept for backwards compatibility. New
-# buildsystems MUST be added to the END of the list.
+# build systems MUST be added to the END of the list.
our @BUILDSYSTEMS = (
"autoconf",
@@ -50,8 +50,8 @@ sub create_buildsystem_instance {
return $module->new(%bsopts);
}
-# Similar to create_buildsystem_instance(), but it attempts to autoselect
-# a buildsystem if none was specified. In case autoselection fails, undef
+# Similar to create_build system_instance(), but it attempts to autoselect
+# a build system if none was specified. In case autoselection fails, undef
# is returned.
sub load_buildsystem {
@@ -88,15 +88,15 @@ sub load_all_buildsystems {
}
}
- # Push debhelper built-in buildsystems first
+ # Push debhelper built-in build systems first
for my $name (@BUILDSYSTEMS) {
@@ -88,15 +88,15 @@ sub load_all_buildsystems {
delete $buildsystems{$name};
}
- # The rest are 3rd party buildsystems
+ # The rest are 3rd party build systems
for my $name (keys %buildsystems) {
my $inst = $buildsystems{$name};
@@ -132,7 +132,7 @@ sub buildsystems_init {
sub buildsystems_list {
my $step=shift;
- # List buildsystems (including auto and specified status)
+ # List build systems (including auto and specified status)
my ($auto, $specified);
my @buildsystems = load_all_buildsystems();